%define fontconfig_major 1
%define lib_name %mklibname %{name} %{fontconfig_major}
%define develname %mklibname %{name} -d

%define freetype_version 2.3.5

%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}
%define rebuild_doc	0
%if %{bootstrap}
%define rebuild_doc 0
%endif

Summary: Font configuration library
Name: fontconfig
Version: 2.15.0
Release: %mkrel 1
License: MIT and Public Domain and UCD
Group: System/X11
Source0: https://fontconfig.org/release/fontconfig-%{version}.tar.xz
# (fc) 2.3.2-3mdk prefer urw fonts
Source1: 30-mdv-urwfonts.conf
# (fc) 2.3.2-3mdk disable antialiasing for some fonts
Source3: 20-mdv-disable-antialias.conf
# (fc) 2.3.2-3mdk  Avoid KDE/QT uses some bitmapped fonts (guisseppe)
Source5: 30-mdv-avoid-bitmap.conf
# (fc) 2.4.2-1mdv disable embedded bitmap for big size (Mdv bug #25924)
Source8: 26-mdv-no-embeddedbitmap.conf
# (fc) 2.4.92-1mdv enable embeddedbitmap on some CJK fonts (Fedora)
Source101: 25-no-bitmap-fedora.conf
# (ovitters) 2.13.90-1mga fc-cache per arch bits (32/64) (Fedora)
Source102: fc-cache
# (ns80) fix PDF rendering in Firefox and Thunderbird (mga bug #32525)
Source103: 70-mga-no-bitmaps-firefox-thunderbird.conf
# (fc) 2.1-4mdk change order of default fonts
Patch50: fontconfig-mdvconfig.patch

# From Fedora as well as upstream:
Patch0: %{name}-sleep-less.patch
Patch5: %{name}-disable-network-required-test.patch

URL: https://fontconfig.org/

Requires: fonts-filesystem
# Register DTD system-wide to make validation work by default
# (used by fonts-rpm-macros)
Requires(pre):    libxml2-utils
Requires(postun): libxml2-utils

Requires(post): %{lib_name}  >= %{version}-%{release}
Requires(post): grep
Requires(post): coreutils

BuildRequires: pkgconfig(freetype2) >= %{freetype_version}
BuildRequires: pkgconfig(uuid)

BuildRequires: ed
%if %{rebuild_doc}
BuildRequires: docbook-utils
BuildRequires: docbook-utils-pdf
BuildRequires: docbook-dtd31-sgml
BuildRequires: docbook-dtd41-sgml
%endif
BuildRequires: lynx
BuildRequires: pkgconfig(libxml-2.0)
BuildRequires: libxml2-utils
BuildRequires: gperf
BuildRequires: docbook-utils
BuildRequires: docbook-utils-pdf

# fwang: add conflicts to ease upgrade
Conflicts:	x11-font-wqy-bitmapfont < 1.0-0.20070901.1

%description
Fontconfig is designed to locate fonts within the
system and select them according to requirements specified by
applications.

%package -n %{lib_name}
Summary: Font configuration and customization library
Group: System/Libraries
Requires: %{name} >= %{version}-%{release}
Provides: lib%{name} = %{version}-%{release}
Provides: %{name}-libs = %{version}-%{release}

%description -n %{lib_name}
Fontconfig is designed to locate fonts within the
system and select them according to requirements specified by
applications.

%package -n %{develname}
Summary: Font configuration and customization library
Group: Development/C
Provides: lib%{name}-devel = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Requires: %{name} = %{version}-%{release}
Requires: %{lib_name} = %{version}-%{release}
Requires: freetype2-devel >= %{freetype_version}
Obsoletes: %{mklibname -d %{name} 1} <= 2.11.1

%description -n %{develname}
The fontconfig-devel package includes the header files,
and developer docs for the fontconfig package.

Install fontconfig-devel if you want to develop programs which
will use fontconfig.

%prep
%autosetup -p1

%build
%if !%{rebuild_doc}
# We don't want to rebuild the docs, but we want to install the included ones.
export HASDOCBOOK=no

for i in doc/*.fncs; do
  touch -r $i ${i//.fncs/.sgml}
done
%endif
autoreconf -fi
%configure --localstatedir=/var \
   --with-add-fonts="/usr/share/fonts,/usr/share/X11/fonts/Type1,/usr/share/X11/fonts/TTF,/usr/local/share/fonts,/usr/lib/X11/fonts,/opt/ttfonts" \
   --enable-libxml2 \
   --with-cache-dir=/usr/lib/fontconfig/cache \
   --disable-static

%make_build

%install
%make_install

install -p -m 0644 %{SOURCE1} %{SOURCE3} %{SOURCE5} %{SOURCE8} %{SOURCE101} %{SOURCE103} %{buildroot}%{_sysconfdir}/fonts/conf.d

# needed in case main config files isn't up to date
cat << EOF > %{buildroot}%{_sysconfdir}/fonts/conf.d/00-cache.conf
<?xml version="1.0"?>
<!DOCTYPE fontconfig SYSTEM "urn:fontconfig:fonts.dtd">
<fontconfig>
<!-- Font cache directory list -->

        <cachedir>/usr/lib/fontconfig/cache</cachedir>
        <cachedir>~/.fontconfig</cachedir>

</fontconfig>
EOF

ln -s %{_datadir}/fontconfig/conf.avail/25-unhint-nonlatin.conf %{buildroot}%{_sysconfdir}/fonts/conf.d

# rename fc-cache binary
mv $RPM_BUILD_ROOT%{_bindir}/fc-cache $RPM_BUILD_ROOT%{_bindir}/fc-cache-%{__isa_bits}

# create link to man page
echo ".so man1/fc-cache.1" > $RPM_BUILD_ROOT%{_mandir}/man1/fc-cache-%{__isa_bits}.1

install -p -m 0755 %{SOURCE102} $RPM_BUILD_ROOT%{_bindir}/fc-cache

# remove unpackaged files
rm -rf %{buildroot}%{_datadir}/doc/fontconfig

# we don't want these
find %{buildroot} -name "*.la" -delete

%find_lang %{name}
%find_lang %{name}-conf

%check
# reported and fixed in https://gitlab.freedesktop.org/fontconfig/fontconfig/-/issues/235
# unfortunately the patch does not apply cleanly, plus depends on a few invasive patches, so
# annoying to apply it
[[ -z "$SOURCE_DATE_EPOCH" ]] && export SOURCE_DATE_EPOCH=0
VERBOSE=1 make check

%post
umask 0022

mkdir -p /usr/lib/fontconfig/cache

[[ -d %{_localstatedir}/cache/fontconfig ]] && rm -rf %{_localstatedir}/cache/fontconfig/* 2> /dev/null || :

# Force regeneration of all fontconfig cache files
# The check for existance is needed on dual-arch installs (the second
#  copy of fontconfig might install the binary instead of the first)
# The HOME setting is to avoid problems if HOME hasn't been reset
if [ -x /usr/bin/fc-cache ] && /usr/bin/fc-cache --version 2>&1 | grep -q %{version} ; then
  HOME=/root /usr/bin/fc-cache -f
fi


%triggerprein -- fontconfig < 2.4.0
rm -f %{_var}/cache/fontconfig/*.cache-2

# rpm filetriggers to update cache
%transfiletriggerin     --  /usr/share/fonts /usr/share/X11/fonts/Type1 /usr/share/X11/fonts/TTF /usr/local/share/fonts /usr/lib/X11/fonts /opt/ttfonts
HOME=/root /usr/bin/fc-cache -s

%transfiletriggerpostun --  /usr/share/fonts /usr/share/X11/fonts/Type1 /usr/share/X11/fonts/TTF /usr/local/share/fonts /usr/lib/X11/fonts /opt/ttfonts
HOME=/root /usr/bin/fc-cache -s

%posttrans
if [ -e %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --add system \
                        "urn:fontconfig:fonts.dtd" \
                        "file://%{_datadir}/xml/fontconfig/fonts.dtd" \
                        %{_sysconfdir}/xml/catalog
fi

%postun
if [ $1 == 0 ] && [ -e %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --del "urn:fontconfig:fonts.dtd"
fi

%files -f %{name}.lang -f %{name}-conf.lang
%doc README.md AUTHORS COPYING doc/fontconfig-user.html doc/fontconfig-user.txt
%{_bindir}/*
%dir %{_sysconfdir}/fonts
%dir %{_sysconfdir}/fonts/conf.d
# those files must NOT have noreplace option
%config %{_sysconfdir}/fonts/fonts.conf
%config %{_sysconfdir}/fonts/conf.d/*.conf
%config %{_sysconfdir}/fonts/conf.d/README
%{_datadir}/fontconfig/
%{_datadir}/gettext/its/*
%{_datadir}/xml/fontconfig/fonts.dtd
%{_mandir}/man1/*
%{_mandir}/man5/*
%dir /usr/lib/fontconfig/cache

%files -n %{lib_name}
%{_libdir}/*.so.%{fontconfig_major}
%{_libdir}/*.so.%{fontconfig_major}.*

%files -n %{develname}
%doc doc/fontconfig-devel doc/fontconfig-devel.txt
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_mandir}/man3/*


%changelog
* Mon Feb 26 2024 kekepower <kekepower> 2.15.0-1.mga10
+ Revision: 2044456
- Update to version 2.15.0

* Fri Dec 15 2023 ns80 <ns80> 2.14.2-2.mga10
+ Revision: 2018211
- add a new config file to fix PDF rendering in Firefox and Thunderbird (mga#32525)

* Sun Feb 12 2023 mrambo3501 <mrambo3501> 2.14.2-1.mga9
+ Revision: 1941036
- version 2.14.2

* Fri Oct 21 2022 tv <tv> 2.14.1-1.mga9
+ Revision: 1898158
- 2.14.1

* Mon Apr 04 2022 tv <tv> 2.14.0-1.mga9
+ Revision: 1843852
- Really don't rebuild docs thus fixing build
- Update to 2.14.0
- 2.13.96
- 2.13.95
- 2.13.94
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ luigiwalser <luigiwalser>
- add two more bugfix patches from fedora

* Sun Mar 28 2021 tv <tv> 2.13.93-5.mga9
+ Revision: 1711282
- Fix postun scriptlet to remove the entry from xml catalog

* Thu Dec 24 2020 tv <tv> 2.13.93-4.mga8
+ Revision: 1663314
- cherry pick some upstream patches
  - Skip leading white space in style.
  - Remove abort from FcCompareSize.
  - Fix memory leaks
  - Check qual and compare for family tests.

* Fri Dec 04 2020 tv <tv> 2.13.93-3.mga8
+ Revision: 1652518
- Add back fullname property at the scan matching phase for the backward compatibility.
  (rhbz#1902881)

* Mon Nov 30 2020 tv <tv> 2.13.93-2.mga8
+ Revision: 1650548
- disable drop-lang-from-pkgkit-format.patch as it breaks rpm font provides generation

* Sun Nov 29 2020 luigiwalser <luigiwalser> 2.13.93-1.mga8
+ Revision: 1650081
- rediff patch 50
- 2.13.93
- remove upstreamed patches and man page
- add BRs to fix docs build
- add patch from fedora to remove test requiring network connectivity

* Fri Apr 10 2020 ovitters <ovitters> 2.13.92-3.mga8
+ Revision: 1566116
- add comment about workaround

* Thu Apr 09 2020 ovitters <ovitters> 2.13.92-2.mga8
+ Revision: 1565852
- remove unneeded freetype require

* Thu Apr 09 2020 ovitters <ovitters> 2.13.92-1.mga8
+ Revision: 1565846
- new version 2.13.92
- sync patches with Fedora
+ danf <danf>
- Switch URLs from http: to https:

* Fri Feb 14 2020 umeabot <umeabot> 2.13.1-2.mga8
+ Revision: 1521550
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Dec 28 2018 luigiwalser <luigiwalser> 2.13.1-1.mga7
+ Revision: 1345836
- 2.13.1
- remove upstreamed patch
- add some upstream patches via fedora

* Sun Sep 23 2018 umeabot <umeabot> 2.13.0-4.mga7
+ Revision: 1297738
- Mageia 7 Mass Rebuild

* Tue Apr 24 2018 wally <wally> 2.13.0-3.mga7
+ Revision: 1222187
- don't own dirs owned by other pkgs

* Thu Apr 12 2018 kekepower <kekepower> 2.13.0-2.mga7
+ Revision: 1218012
- Add upstream patch to fix broken emacs

* Tue Mar 27 2018 kekepower <kekepower> 2.13.0-1.mga7
+ Revision: 1212832
- BR uuid
- Update to version 2.13.0
- Rediffed patch

* Fri Sep 29 2017 tv <tv> 2.12.6-1.mga7
+ Revision: 1161478
- drop patch 3 as it breaks testsuite
- rediff patch (some bit was merged upstream modulo s/(Microsoft YaHei) UI/\1/)
- new release

* Mon Jul 24 2017 joequant <joequant> 2.12.4-2.mga7
+ Revision: 1129815
- fix 21206 - fix sans-serif in Chinese microsoft fonts

* Wed Jul 19 2017 tv <tv> 2.12.4-1.mga7
+ Revision: 1125099
- BR gperf
- new release

* Thu Jan 19 2017 daviddavid <daviddavid> 2.12.1-2.mga6
+ Revision: 1082464
- add patch from Arch Linux to fix test with freetype2 2.7.1

* Tue Aug 09 2016 akien <akien> 2.12.1-1.mga6
+ Revision: 1045184
- Version 2.12.1
  o Upstreams sec patch for CVE-2016-5384
  o Adds --with-default-hinting option (might help fix mga#18488)

* Mon Aug 08 2016 luigiwalser <luigiwalser> 2.12.0-2.mga6
+ Revision: 1045006
- add upstream patch to fix CVE-2016-5384

* Tue Jun 28 2016 tmb <tmb> 2.12.0-1.mga6
+ Revision: 1038023
- update to 2.12.0 final

* Mon May 09 2016 luigiwalser <luigiwalser> 2.11.95-1.mga6
+ Revision: 1011358
- 2.11.95
- remove patch 3 (fixed upstream)

* Thu Feb 11 2016 umeabot <umeabot> 2.11.94-2.mga6
+ Revision: 953960
- Mageia 6 Mass Rebuild
+ tv <tv>
- switch to pkgconfig() BRs

* Sun Sep 13 2015 ycantin <ycantin> 2.11.94-1.mga6
+ Revision: 878930
- new version 2.11.94
  rediff fontconfig-mdvconfig.patch
  sync Fedora patchs

* Sat Sep 05 2015 tv <tv> 2.11.1-5.mga6
+ Revision: 873137
- switch to new upstream file trigger syntax
- add more font paths from FC
- drop obsolete /usr/X11R6/lib/X11/fonts path

* Wed Oct 15 2014 umeabot <umeabot> 2.11.1-4.mga5
+ Revision: 744720
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.11.1-3.mga5
+ Revision: 679254
- Mageia 5 Mass Rebuild

* Wed Aug 06 2014 fwang <fwang> 2.11.1-2.mga5
+ Revision: 660320
- promote source han at first

* Sat Mar 29 2014 luigiwalser <luigiwalser> 2.11.1-1.mga5
+ Revision: 609638
- 2.11.1

* Tue Oct 22 2013 umeabot <umeabot> 2.11.0-2.mga4
+ Revision: 541353
- Mageia 4 Mass Rebuild

* Sat Oct 12 2013 fwang <fwang> 2.11.0-1.mga4
+ Revision: 495666
- new version 2.11.0

* Sun Sep 01 2013 tmb <tmb> 2.10.95-1.mga4
+ Revision: 474023
- 2.10.95 (crash fix)

* Sat Aug 31 2013 luigiwalser <luigiwalser> 2.10.94-1.mga4
+ Revision: 473609
- 2.10.94

* Sun May 26 2013 blino <blino> 2.10.93-1.mga4
+ Revision: 428238
- 2.10.93

* Fri Jan 11 2013 umeabot <umeabot> 2.10.2-2.mga3
+ Revision: 350644
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 27 2012 fwang <fwang> 2.10.2-1.mga3
+ Revision: 322235
- new version 2.10.2

* Fri Aug 03 2012 fwang <fwang> 2.10.1-3.mga3
+ Revision: 278107
- drop more invalid rules

* Tue Jul 31 2012 fwang <fwang> 2.10.1-2.mga3
+ Revision: 276551
- delete rules that are not used any more

* Fri Jul 27 2012 fwang <fwang> 2.10.1-1.mga3
+ Revision: 274803
- new version 2.10.1
+ yochenhsieh <yochenhsieh>
- Alter default zh_TW font order in conf

* Tue Jul 17 2012 fwang <fwang> 2.10-2.mga3
+ Revision: 271708
- fix symlink

* Tue Jul 17 2012 fwang <fwang> 2.10-1.mga3
+ Revision: 271698
- update file list
- fix dtd checking
- do not build doc for now
- new version 2.10
+ yochenhsieh <yochenhsieh>
- Update/fix patch format errors
- Set AR PL Uming TW for zh-tw default

* Fri Jun 08 2012 fwang <fwang> 2.9.0-1.mga3
+ Revision: 257473
- new version 2.9.0

* Sun Oct 09 2011 wally <wally> 2.8.0-6.mga2
+ Revision: 153560
- disable static build and get rid of .la files
+ blino <blino>
- remove old ldconfig scriptlets
- imported package fontconfig

